@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2005 James Stembridge                                   *
- *   jstembridge@gmail.com                                                 *
+ *   Copyright (C) 2005 by James Stembridge <jstembridge@gmail.com>        *
+ *   Copyright (C) 2007 by Raphael Geissert <atomo64@gmail.com>            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -19,6 +19,8 @@
  ***************************************************************************/
 
 #include "dcopobject.h"
+#include <qstringlist.h>
+#include <qmap.h>
 
 class KCheckGmailIface : virtual public DCOPObject
 {
@@ -27,7 +29,16 @@ class KCheckGmailIface : virtual public DCOPObject
 	
 	virtual int mailCount() const = 0;
 	virtual void checkMailNow() = 0;
-	virtual void snooze() = 0;
 	virtual void whereAmI() = 0;
+	virtual void showIcon() = 0;
+	virtual void hideIcon() = 0;
+	virtual QStringList getThreads() = 0;
+	virtual QString getThreadSubject(QString msgId) = 0;
+	virtual QString getThreadSender(QString msgId) = 0;
+	virtual QString getThreadSnippet(QString msgId) = 0;
+	virtual QStringList getThreadAttachments(QString msgId) = 0;
+	virtual bool isNewThread(QString msgId) = 0;
+	virtual QMap<QString, unsigned int> getLabels() = 0;
+	virtual QString getGaiaName() = 0;
 };
 
